@@ -64,11 +64,6 @@ namespace bareFTP.Gui.FileManager
 			this.Selection.Mode = Gtk.SelectionMode.Multiple;
 			
 			DragBegin += HandleHandleDragBegin;
-			DragMotion += HandleHandleDragMotion;
-			//this.EnableGridLines = Gtk.TreeViewGridLines.Vertical;
-			//this.RubberBanding = true;
-			//RulesHint = true;
-			
 			dragItems = new List<TreePath>();
 			
 			Gtk.TreeViewColumn fileColumn = new Gtk.TreeViewColumn ();
@@ -101,34 +96,38 @@ namespace bareFTP.Gui.FileManager
 			
 			MyCellRendererPixbuf iconCell = new MyCellRendererPixbuf();
 			MyCellRendererText fileCell = new MyCellRendererText();
+			
 			fileColumn.PackStart(iconCell, false);
 			fileColumn.PackStart(fileCell, false);
-			fileColumn.SetCellDataFunc (fileCell, new Gtk.TreeCellDataFunc (RenderFileName));
+			
+			fileColumn.AddAttribute (iconCell, "pixbuf", 1);
+			fileColumn.AddAttribute (fileCell, "text", 2);
+			
 			fileColumn.FixedWidth = 180;
 			
 			MyCellRendererText sizeCell = new MyCellRendererText();
 			sizeColumn.PackStart(sizeCell, false);
-			sizeColumn.SetCellDataFunc (sizeCell, new Gtk.TreeCellDataFunc (RenderSize));
+			sizeColumn.SetAttributes(sizeCell, "text", 3);
 			sizeColumn.FixedWidth = 80;
 			
 			MyCellRendererText dateCell = new MyCellRendererText();
 			dateColumn.PackStart(dateCell, false);
-			dateColumn.SetCellDataFunc (dateCell, new Gtk.TreeCellDataFunc (RenderDate));
+			dateColumn.SetAttributes(dateCell, "text", 4);
 			dateColumn.FixedWidth = 160;
 			
 			MyCellRendererText userCell = new MyCellRendererText();
 			userColumn.PackStart(userCell, false);
-			userColumn.SetCellDataFunc (userCell, new Gtk.TreeCellDataFunc (RenderUser));
+			userColumn.SetAttributes(userCell, "text", 5);
 			userColumn.FixedWidth = 60;
 			
 			MyCellRendererText groupCell = new MyCellRendererText();
 			groupColumn.PackStart(groupCell, false);
-			groupColumn.SetCellDataFunc (groupCell, new Gtk.TreeCellDataFunc (RenderGroup));
+			groupColumn.SetAttributes(groupCell, "text", 6);
 			groupColumn.FixedWidth = 60;
 			
 			MyCellRendererText privsCell = new MyCellRendererText();
 			privsColumn.PackStart(privsCell, false);
-			privsColumn.SetCellDataFunc (privsCell, new Gtk.TreeCellDataFunc (RenderFilePrivs));
+			privsColumn.SetAttributes(privsCell, "text", 7);
 			privsColumn.FixedWidth = 100;
 			
 			this.AppendColumn(fileColumn);
@@ -145,42 +144,6 @@ namespace bareFTP.Gui.FileManager
 			}
 		}
 
-		[GLib.ConnectBefore] 
-		void HandleHandleDragMotion (object o, DragMotionArgs args)
-		{
-			
-			/*
-			TreePath path;
-			TreeIter iter;
-       		TreeViewDropPosition pos;
-       		TreeViewDropPosition overrideDrop;
-			
-			if (!GetDestRowAtPos (args.X, args.Y, out path, out pos))
-               return;
-			
-			overrideDrop = pos;
-			Model.GetIter(out iter, path);
-			FileTreeNode node = (FileTreeNode)Model.GetValue(iter,0);
-			
-			if(pos == TreeViewDropPosition.IntoOrAfter)
-			{
-				if(!node.IsDir)
-					overrideDrop = TreeViewDropPosition.After;
-			}
-			else if(pos == TreeViewDropPosition.IntoOrBefore)
-			{
-				if(!node.IsDir)
-					overrideDrop = TreeViewDropPosition.Before;
-			}
-			else
-				return;
-			
-        	SetDragDestRow (path, overrideDrop);
-        	Gdk.Drag.Status (args.Context, args.Context.SuggestedAction, args.Time);
-        	args.RetVal = true; 
-        	*/
-		}
-		
 		public bareFTP.Protocol.ProtocolType ProtocolType
 		{
 			set { ptype = value; }
@@ -254,61 +217,6 @@ namespace bareFTP.Gui.FileManager
 			Model = model;
 		}
 		
-		private void RenderFileName (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
-		{
-			    
-			FileTreeNode node = (FileTreeNode)model.GetValue(iter, 0);
-			(cell as MyCellRendererText).Text = node.FileName;
-			
-			foreach(Gtk.CellRenderer c in column.CellRenderers)
-			{
-				if(c is MyCellRendererPixbuf)
-				{
-					MyCellRendererPixbuf iconcell = (MyCellRendererPixbuf)c;
-					iconcell.Pixbuf = node.Type;
-				}
-			}
-		}
-		
-		private void RenderSize (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
-		{
-			FileTreeNode node = (FileTreeNode)model.GetValue(iter, 0);
-			string size = string.Empty;
-			if(!node.IsDir)
-			{
-				if(node.Size >= 0)
-					size = Gnome.Vfs.Format.FileSizeForDisplay(node.Size);
-			}
-			(cell as MyCellRendererText).Text = size;
-		}
-		
-		private void RenderDate (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
-		{
-			FileTreeNode node = (FileTreeNode)model.GetValue(iter, 0);
-			if(node.Date < DateTime.MaxValue)
-				(cell as MyCellRendererText).Text = node.Date.ToString("r");
-			else
-				(cell as MyCellRendererText).Text = string.Empty;
-		}
-		
-		private void RenderUser (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
-		{
-			FileTreeNode node = (FileTreeNode)model.GetValue(iter, 0);
-			(cell as MyCellRendererText).Text = node.User;
-		}
-		
-		private void RenderGroup (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
-		{
-			FileTreeNode node = (FileTreeNode)model.GetValue(iter, 0);
-			(cell as MyCellRendererText).Text = node.Group;
-		}
-		
-		private void RenderFilePrivs (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
-		{
-			FileTreeNode node = (FileTreeNode)model.GetValue(iter, 0);
-			(cell as MyCellRendererText).Text = node.Rights;
-		}
-
 		#region Properties
 		
 		public bool ShowHiddenFiles
@@ -316,6 +224,21 @@ namespace bareFTP.Gui.FileManager
 			get { return conf.General_ShowHiddenFiles; }
 		}
 		
+		public bool DirectoryExisist(string directory)
+		{
+			Gtk.TreeIter iter;
+			bool keepgoing = Model.GetIterFirst(out iter);
+			while(keepgoing)
+			{
+				FileTreeNode fn = (FileTreeNode)this.Model.GetValue(iter,0);
+				if(fn.IsDir && (fn.FileName == directory))
+					return true;
+				keepgoing = Model.IterNext(ref iter);
+			}
+			
+			return false;
+		}
+		
 		public List<string> SelectedFiles
     	{
     		get 
@@ -402,9 +325,14 @@ namespace bareFTP.Gui.FileManager
 			Gtk.CellRendererText cr = FileNameCell;
 			cr.Editable = true;
 			cr.Edited += FileName_Edited;
-			
+			cr.EditingCanceled += HandleCrEditingCanceled;
 			SetCursorOnCell(path, GetColumn(0), cr, true);
 		}
+
+		void HandleCrEditingCanceled (object sender, EventArgs e)
+		{
+			DirectoryChanged(new DirectoryChangedArgs(string.Empty));
+		}
 		
 		private void FileName_Edited (object o, Gtk.EditedArgs args)
 		{	
@@ -428,9 +356,9 @@ namespace bareFTP.Gui.FileManager
 			cr.Editable = false;
 			cr.Edited -= File_Renamed;
 			
-			FileTreeNode node = SelectedFileNodes[0]; 
-			FileRenameRequest(new FileRenamedArgs(node.FileName, args.NewText));
-			
+			FileTreeNode node = SelectedFileNodes[0];
+			if(!string.IsNullOrEmpty(args.NewText))
+				FileRenameRequest(new FileRenamedArgs(node.FileName, args.NewText));
 		}
 		
 		[GLib.ConnectBefore]
