@@ -338,7 +338,7 @@ namespace bareFTP.Gui.FileManager
 		
 		public bool ChangeDirSynchronized(string nPath)
 		{
-			if(filelist.DirectoryExisist(nPath))
+			if(filelist.DirectoryExisist(nPath) || string.IsNullOrEmpty(nPath))
 			{
 				ChangeDir(nPath);
 				return true;
