@@ -240,7 +240,7 @@ namespace bareFTP.Gui.FileManager
 		
 		public bool ChangeDirSynchronized(string nPath)
 		{
-			if(filelist.DirectoryExisist(nPath))
+			if(filelist.DirectoryExisist(nPath) || string.IsNullOrEmpty(nPath))
 			{
 				ChangeDir(nPath, true, true, false);
 				return true;
