@@ -41,7 +41,13 @@ namespace bareFTP.Gui.Preferences
 			
 			combo_remote_charset.AppendText("");
 			foreach(System.Text.EncodingInfo i in System.Text.Encoding.GetEncodings())
-				combo_remote_charset.AppendText(i.DisplayName);
+			{
+				try 
+				{
+					combo_remote_charset.AppendText(i.DisplayName);
+				}
+				catch {}
+			}
 			
 			combo_remote_charset.Changed += on_remote_charset_changed;
 			
