@@ -120,6 +120,22 @@ namespace bareFTP.Preferences
 				client.Set(GCONF_APP_PATH + "/general/show_hidden_files", value);
 			}
 		}
+		
+		public bool General_EnableDirectoryCache
+		{
+			get 
+			{ 
+				try {
+					return (bool)client.Get(GCONF_APP_PATH + "/general/enable_directory_cache");
+				} catch (GConf.NoSuchKeyException) {
+					return true;
+				}
+			}
+			set 
+			{
+				client.Set(GCONF_APP_PATH + "/general/enable_directory_cache", value);
+			}
+		}
 
 		public bool General_PreserveFilePermissions
 		{
