@@ -112,14 +112,12 @@ namespace bareFTP.Protocol.Ftp
 				
 				SslStream sslstream = new SslStream(tcpClient.GetStream(), false, CertificateValidation);
 				
-				
 				try
 				{
 					sslstream.AuthenticateAsClient(remoteHost);
 				}
 				catch(Exception ex)
 				{
-					
 					reader.Close();
 					reader.Dispose();
 					reader = null;
@@ -145,8 +143,8 @@ namespace bareFTP.Protocol.Ftp
 			
 			try
 			{ 
-				CheckReply(SendCommand("USER " + user), 331);
-				CheckReply(SendCommand("PASS " + password), 230);
+				CheckReply(SendCommand(string.Format("USER {0}",user)), 331);
+				CheckReply(SendCommand(string.Format("PASS {0}", password)), 230);
 			}
 			catch(Exception e)
 			{ 
@@ -187,7 +185,16 @@ namespace bareFTP.Protocol.Ftp
 		public void Close()
 		{
 			if(tcpClient.Connected)
-				CheckReply(SendCommand("QUIT"), 221);
+			{
+				try
+				{
+					CheckReply(SendCommand("QUIT"), 221);
+				}
+				catch
+				{
+					tcpClient.Close();	
+				}
+			}
 			if(tcpClient.Connected)
 				tcpClient.Close();
 		}
@@ -222,8 +229,21 @@ namespace bareFTP.Protocol.Ftp
 				
 			Byte[] cmdBytes = GetEncoding().GetBytes((command+EOL).ToCharArray());
 			OnLogTextEmitted(new LogTextEmittedArgs(-1, command));
-			writer.BaseStream.Write(cmdBytes, 0, cmdBytes.Length);
-			writer.Flush();
+			try
+			{
+				if(writer.BaseStream.CanWrite)
+				{
+					writer.BaseStream.Write(cmdBytes, 0, cmdBytes.Length);
+					writer.Flush();
+				}
+				else
+					throw new Exception("Can't write to network stream");
+			}
+			catch(Exception ex)
+			{
+				OnLogTextEmitted(new LogTextEmittedArgs(MessageType.Error, ex.Message));
+				return null;
+			}
 			return GetReply();
 		}
 		
@@ -252,24 +272,24 @@ namespace bareFTP.Protocol.Ftp
 		
 		public void ChangeDir(string dir)
 		{
-			CheckReply(SendCommand("CWD " + dir), 250);
+			CheckReply(SendCommand(string.Format("CWD {0}", dir)), 250);
 		}
 		
 		public bool IsDir(string cwd, string dir)
 		{
 			bool isdir = false;
-			foreach(FTPReply reply in SendCommand("CWD " + dir))
+			foreach(FTPReply reply in SendCommand(string.Format("CWD {0}", dir)))
 			{
 				if(reply.ReplyCode == 250)
 					isdir = true;
 			}
-			SendCommand("CWD " + cwd);
+			SendCommand(string.Format("CWD {0}", cwd));
 			return isdir;
 		}
 		
 		public void MakeDir(string directoryName)
 		{
-			CheckReply(SendCommand("MKD " + directoryName), 257);
+			CheckReply(SendCommand(string.Format("MKD {0}", directoryName)), 257);
 		}
 		
 		public List<string> XDir()
@@ -338,7 +358,7 @@ namespace bareFTP.Protocol.Ftp
 			{
 				if(features.Contains("PRET") || features.Contains("pret"))
 				{
-						CheckReply(SendCommand("PRET RETR " + file.Path.FileNameRemoteAbs), true, 200);
+						CheckReply(SendCommand(string.Format("PRET RETR {0}", file.Path.FileNameRemoteAbs)), true, 200);
 				}	
 			}
 			DataSocket dsocket = CreateDataSocket();
@@ -348,10 +368,10 @@ namespace bareFTP.Protocol.Ftp
 			if(action == FileAction.Resume)
 			{
 				file.TransferedBytes = fstream.Length;
-				CheckReply(SendCommand("REST " + fstream.Length.ToString()), 350);
+				CheckReply(SendCommand(string.Format("REST {0}", fstream.Length.ToString())), 350);
 			}
 							
-			CheckReply(SendCommand("RETR " + file.Path.FileNameRemoteAbs), 125, 150);
+			CheckReply(SendCommand(string.Format("RETR {0}", file.Path.FileNameRemoteAbs)), 125, 150);
 			
 			file.Status = bareFTP.Protocol.DownloadStatus.Downloading;
 			
@@ -398,9 +418,9 @@ namespace bareFTP.Protocol.Ftp
 				if(features.Contains("PRET") || features.Contains("pret"))
 				{
 					if(action == FileAction.Resume || action == FileAction.Append)
-						CheckReply(SendCommand("PRET APPE " + file.Path.FileNameRemoteAbs), true, 200);
+						CheckReply(SendCommand(string.Format("PRET APPE {0}", file.Path.FileNameRemoteAbs)), true, 200);
 					else
-						CheckReply(SendCommand("PRET STOR " + file.Path.FileNameRemoteAbs), true, 200);
+						CheckReply(SendCommand(string.Format("PRET STOR {0}", file.Path.FileNameRemoteAbs)), true, 200);
 				}
 			}
 			
@@ -408,17 +428,17 @@ namespace bareFTP.Protocol.Ftp
 			long fslength = fstream.Length;
 			if(action == FileAction.Resume)
 			{
-				CheckReply(SendCommand("APPE " + file.Path.FileNameRemoteAbs), 125, 150);
+				CheckReply(SendCommand(string.Format("APPE {0}", file.Path.FileNameRemoteAbs)), 125, 150);
 				fstream.Position = file.Marker;
 				fslength = fslength - file.Marker;
 				file.TransferedBytes = file.Marker;
 			}
 			else if(action == FileAction.Append)
 			{
-				CheckReply(SendCommand("APPE " + file.Path.FileNameRemoteAbs), 125, 150);
+				CheckReply(SendCommand(string.Format("APPE {0}", file.Path.FileNameRemoteAbs)), 125, 150);
 			}
 			else
-				CheckReply(SendCommand("STOR " + file.Path.FileNameRemoteAbs), 125, 150);
+				CheckReply(SendCommand(string.Format("STOR {0}", file.Path.FileNameRemoteAbs)), 125, 150);
 			
 			Stream networkStream = dsocket.GetStream();
 
@@ -467,8 +487,25 @@ namespace bareFTP.Protocol.Ftp
 				// read first line
 				//if(reader == null)
 				//	return replies;
+				string line = string.Empty;
 				
-				string line = reader.ReadLine();
+				try
+				{
+					line = reader.ReadLine();
+				}
+				catch(IOException)
+				{
+					System.Threading.Thread.Sleep(200);
+					try
+					{
+						line = reader.ReadLine();
+					}
+					catch(IOException ex)
+					{
+						OnLogTextEmitted(new LogTextEmittedArgs(MessageType.Error, "Network error: " + ex.Message));
+						return null;
+					}
+				}
 				
 				while (line != null && line.Length == 0)
 				{					
@@ -531,7 +568,7 @@ namespace bareFTP.Protocol.Ftp
 		
 		public void Delete(string filename)
 		{
-			CheckReply(SendCommand("DELE " + filename), 250);	
+			CheckReply(SendCommand(string.Format("DELE {0}", filename)), 250);	
 		}
 		
 		public void Abort()
@@ -542,7 +579,7 @@ namespace bareFTP.Protocol.Ftp
 		
 		public void RemoveDir(string dirname)
 		{
-			CheckReply(SendCommand("RMD " + dirname), 250);
+			CheckReply(SendCommand(string.Format("RMD {0}", dirname)), 250);
 		}
 
 		public void Chmod(string mode, string filename)
@@ -552,14 +589,14 @@ namespace bareFTP.Protocol.Ftp
 		
 		public void Chmod(string mode, string filename, bool silent)
 		{
-			CheckReply(SendCommand(String.Format("SITE CHMOD {0} {1}", mode, filename)), silent, 200);
+			CheckReply(SendCommand(string.Format("SITE CHMOD {0} {1}", mode, filename)), silent, 200);
 		}
 		
 		public void RenameFile(string fromRemoteFileName, string toRemoteFileName)
 		{
 		
-			CheckReply(SendCommand("RNFR " + fromRemoteFileName), 350);
-			CheckReply(SendCommand("RNTO " + toRemoteFileName), 250);
+			CheckReply(SendCommand(string.Format("RNFR {0}", fromRemoteFileName)), 350);
+			CheckReply(SendCommand(string.Format("RNTO {0}", toRemoteFileName)), 250);
 		}
 		
 		internal List<string> ReadLines(Stream stream)
@@ -631,9 +668,12 @@ namespace bareFTP.Protocol.Ftp
 				int portHigh = port >> 8;
 				int portLow = port & 255;
 				
-				CheckReply(SendCommand("PORT " + GetLocalAddressList()[0].ToString().Replace(".", ",")
-				                         + "," + portHigh.ToString() + "," + portLow), 200);
+				string command = string.Format("PORT {0}, {1}, {2}", 
+				                               GetLocalAddressList()[0].ToString().Replace(".", ","),
+				                               portHigh.ToString(),
+				                               portLow.ToString());
 				
+				CheckReply(SendCommand(command), 200);
 			}
 			
 			string plevel;
