@@ -411,8 +411,9 @@ namespace bareFTP.Protocol.Sftp
 				}
 
 				int i=buf.getInt();
-				if(i==SSH_FX_OK) return;
-				throwStatusError(buf, i);
+				if(i==SSH_FX_OK) 
+					return;
+				throwStatusError(buf, i, "rename");
 			}
 			catch(System.Exception e)
 			{
@@ -459,7 +460,8 @@ namespace bareFTP.Protocol.Sftp
 					int i=buf.getInt();
 					if(i==SSH_FX_EOF)
 						break;
-					throwStatusError(buf, i);
+					
+					throwStatusError(buf, i, "xdir");
 				}
 				
 				buf.rewind();
@@ -543,7 +545,7 @@ namespace bareFTP.Protocol.Sftp
 				{
 					int i=buf.getInt();
 					//throw new Exception("Tjohei");
-					throwStatusError(buf, i);
+					throwStatusError(buf, i, "myget");
 				}
 				
 				byte[] handle=buf.getString();         // filename
@@ -587,7 +589,7 @@ namespace bareFTP.Protocol.Sftp
 						{
 							break;
 						}
-						throwStatusError(buf, i);
+						throwStatusError(buf, i, "myget");
 					}
 					
 					if(type!=SSH_FXP_DATA)
@@ -641,7 +643,7 @@ namespace bareFTP.Protocol.Sftp
 			}
 			catch(System.Exception e)
 			{
-				
+				System.Console.WriteLine("Error2: " + e.ToString());
 				System.Console.WriteLine("Error: " + e.ToString());
 				//System.Console.WriteLine("Src: " + src.FileName);
 				
@@ -705,7 +707,7 @@ namespace bareFTP.Protocol.Sftp
 				{
 					int i=buf.getInt();
 					//Console.WriteLine("StatusError");
-					throwStatusError(buf, i);
+					throwStatusError(buf, i, "myput");
 				}
 				
 				byte[] handle = buf.getString();
@@ -802,7 +804,7 @@ namespace bareFTP.Protocol.Sftp
 
 				int i=buf.getInt();
 				if(i==SSH_FX_OK) return;
-				throwStatusError(buf, i);
+				throwStatusError(buf, i, "mkdir");
 			}
 			catch(System.Exception e)
 			{
@@ -844,7 +846,7 @@ namespace bareFTP.Protocol.Sftp
 					int i=buf.getInt();
 					if(i!=SSH_FX_OK)
 					{
-						throwStatusError(buf, i);
+						throwStatusError(buf, i, "rmdir");
 					}
 				}
 			}
@@ -909,7 +911,7 @@ namespace bareFTP.Protocol.Sftp
 					int i=buf.getInt();
 					if(i != SSH_FX_OK)
 					{
-						throwStatusError(buf, i);
+						throwStatusError(buf, i, "rm");
 					}
 				}
 			}
@@ -935,17 +937,17 @@ namespace bareFTP.Protocol.Sftp
 			public int rid;
 		}
 		
-		private void throwStatusError(Buffer buf, int i) 
+		private void throwStatusError(Buffer buf, int i, string method) 
 		{ 
 			if(server_version>=3)
 			{
 				byte[] str=buf.getString();
 				//byte[] tag=buf.getString();
-				throw new SftpException(i, System.Text.Encoding.UTF8.GetString(str));
+				throw new SftpException(i, method + ": " + System.Text.Encoding.UTF8.GetString(str));
 			}
 			else
 			{
-				throw new SftpException(i, "Failure");
+				throw new SftpException(i, method + " failure");
 			}
 		}
 		
@@ -1023,7 +1025,7 @@ namespace bareFTP.Protocol.Sftp
 				if(type==SSH_FXP_STATUS)
 				{
 					int i=buf.getInt();
-					throwStatusError(buf, i);
+					throwStatusError(buf, i, "_stat");
 				}
 				//throw new SftpException(SSH_FX_FAILURE, "");
 			}
@@ -1054,7 +1056,7 @@ namespace bareFTP.Protocol.Sftp
 				int i=buf.getInt();
 				if(i!=SSH_FX_OK)
 				{
-					throwStatusError(buf, i);
+					throwStatusError(buf, i, "_setStat");
 				}
 			}
 			catch(System.Exception e)
