@@ -20,6 +20,7 @@
 using System;
 using System.Net;
 using System.Net.Sockets;
+using System.Globalization;
 
 namespace bareFTP.Protocol
 {
@@ -27,7 +28,9 @@ namespace bareFTP.Protocol
     {
         public static IPAddress GetAddress(string hostName)
         {
-			IPAddress[] addresses = Dns.GetHostAddresses(hostName);
+			IdnMapping idn = new IdnMapping();
+			
+			IPAddress[] addresses = Dns.GetHostAddresses(idn.GetAscii(hostName));
 			
 			foreach (IPAddress a in addresses)
             	if (a.AddressFamily == System.Net.Sockets.AddressFamily.InterNetwork)
