@@ -57,6 +57,9 @@ Spanish (es):
 	Innocent De Marchi <tangram.peces@gmail.com>
 French (fr): 
 	Simon Leblanc <contact@leblanc-simon.eu>
+	Vincent Blut <vincent.debian@free.fr>
+Hungarian (hu):
+	Adam Pongracz <pongadam@gmail.com>
 Italian (it): 
 	Gianvito Cavasoli <gianvito@gmx.it>
 Japanese (ja):
