@@ -51,12 +51,12 @@ namespace bareFTP
 		private string remote_server = string.Empty;
 		private Preferences.Config conf;
 		private uint statusbar_context_id;
+		private uint statusbar2_context_id;
 		private Gui.ActivityProgressBar progressbar;
 		private System.Threading.Thread connectthread;
 		private Gui.KeyBinder keybindings;
 		private AccelGroup agroup;
 		
-		
 		public MainWindow (Preferences.Config conf, bool debug): base (Gtk.WindowType.Toplevel)
 		{
 			
@@ -142,10 +142,10 @@ namespace bareFTP
 			
 			file_local.DownloadRequest += onDownloadClicked;
 			file_local.UploadRequest += onUploadClicked;
-			
+			file_local.DirChanged += onLocalDirChanged;
 			file_remote.DownloadRequest += onDownloadClicked;
 			file_remote.UploadRequest += onUploadClicked;
-			
+			file_remote.DirChanged += onRemoteDirChanged;
 			file_remote.UserAction += on_user_action;
 			file_local.ChangeDir(System.Environment.GetFolderPath(System.Environment.SpecialFolder.Personal));
 			file_remote.ChangeDir(null, false);
@@ -164,7 +164,9 @@ namespace bareFTP
 			this.btn_ClearTransfers.TooltipText = Mono.Unix.Catalog.GetString("Clear finished transfers");
 			this.WindowStateEvent += winstate;
 			this.ExposeEvent += exposed;
+			
 			statusbar_context_id = statusbar1.GetContextId("ErrorMsg");
+			statusbar2_context_id = statusbar2.GetContextId("StateInfo");
 			
 			bookmarkutils = new bareFTP.Gui.BookmarkUtils();
 			bookmarkutils.BookmarkMenuBar = menubar1;
@@ -188,6 +190,7 @@ namespace bareFTP
 					Title = title;
 				}
 			};
+			
 		}
 		
 		
@@ -211,6 +214,7 @@ namespace bareFTP
 			entryPassword.Text = entry.Pass;
 			entryPort.Text = entry.Port;
 			combobox1.Active = entry.Protocol - 1;
+			SynchronizedBrowsingAction.Active = entry.SyncedBrowse;
 			Connect(entry);
 		}
 		protected void winstate(object sender, Gtk.WindowStateEventArgs args)
@@ -228,9 +232,29 @@ namespace bareFTP
 				this.ExposeEvent -= exposed;
 		}
 		
+		protected void onLocalDirChanged(object sender, EventArgs args)
+		{
+			if(SynchronizedBrowsingAction.Active)
+				if(!file_remote.ChangeDirSynchronized(sender.ToString()))
+					DisableSynchBrowsing();
+		}
+		
+		protected void onRemoteDirChanged(object sender, EventArgs args)
+		{
+			if(SynchronizedBrowsingAction.Active)
+				if(!file_local.ChangeDirSynchronized(sender.ToString()))
+					DisableSynchBrowsing();
+		}
+		
+		private void DisableSynchBrowsing()
+		{
+			SynchronizedBrowsingAction.Active = false;
+			this.statusbar2.Pop(statusbar2_context_id);
+			this.statusbar2.Push(statusbar2_context_id, Mono.Unix.Catalog.GetString("Syncronized browsing disabled"));
+		}
+		
 		private void Upload(List<LocalFile> files, BarePath bpath)
 		{
-			
 			bpath.SetBaseLocal(file_local.CurrentDir.LocalPath);
 			statusbar1.Pop(statusbar_context_id);
 			
@@ -314,7 +338,7 @@ namespace bareFTP
 				AskFileAction md = new AskFileAction(xferfiles);
 				ResponseType result = (ResponseType)md.Run ();
 
-				if (result == ResponseType.Cancel)
+				if (result != ResponseType.Ok)
 				{
 					md.Destroy();
 					return;
@@ -437,7 +461,7 @@ namespace bareFTP
 				AskFileAction md = new AskFileAction(xferfiles);
 				ResponseType result = (ResponseType)md.Run ();
 
-				if (result == ResponseType.Cancel)
+				if (result != ResponseType.Ok)
 				{
 					md.Destroy();
 					return;
@@ -812,7 +836,7 @@ namespace bareFTP
 			{
 				conn.Close();
 				file_remote.RemoveConnection();
-			} catch{}
+			} catch {}
 			
 			progressbar.Stop();
 			file_remote.Sensitive = true;
@@ -849,7 +873,7 @@ namespace bareFTP
 					ad.Destroy();
 				}
 			}
-			SetStatusBarMessage("Connecting...", false);
+			SetStatusBarMessage(Mono.Unix.Catalog.GetString("Connecting") + "...", false);
 			
 			btnConnect.Sensitive = false;
 			conn_props = new ConnectionProperties();
@@ -870,7 +894,7 @@ namespace bareFTP
 			{
 				if(!Int32.TryParse(entryPort.Text, out port))
 				{
-					Gui.Dialog.Dialogs.ErrorDialog("Invalid port number");
+					Gui.Dialog.Dialogs.ErrorDialog(Mono.Unix.Catalog.GetString("Invalid port number"));
 				}
 			}
 			
@@ -943,7 +967,7 @@ namespace bareFTP
 				
 				if(conn != null && conn.Connected)
 				{
-					SetStatusBarMessage("Connected", false);
+					SetStatusBarMessage(Mono.Unix.Catalog.GetString("Connected"), false);
 					
 					// Give our connection to the remote file manager.
 					// TODO: This may have to be changed, so the remote file manager controls this itself.
@@ -1079,6 +1103,12 @@ namespace bareFTP
 			}
 			
 			bareFTP.Gui.Preferences.BookmarkDialog d = new bareFTP.Gui.Preferences.BookmarkDialog(conn.ConnProperties);
+			
+			d.NewBookmarkLocalPath = file_local.CurrentDir.LocalPath;
+			d.NewBookmarkRemotePath = file_remote.CurrentDir.RemotePathAbs;
+			d.NewBookmarkSyncedBrowse = SynchronizedBrowsingAction.Active;
+			d.InsertNewBookmark();
+			
 			//Consider using cancel in the dialog.. now we always save..
 			d.Run();
 			d.SaveBookmarks();
@@ -1127,5 +1157,13 @@ namespace bareFTP
 			return bareFTP.Gui.Dialog.Dialogs.QuestionDialog(Mono.Unix.Catalog.GetString("This will close the current connection. Do you want to continue connecting?"));
 		}
 		
+		protected virtual void onSynchBrowseToggeled (object sender, System.EventArgs e)
+		{
+			this.statusbar2.Pop(statusbar2_context_id);
+			if(SynchronizedBrowsingAction.Active)
+				this.statusbar2.Push(statusbar2_context_id, Mono.Unix.Catalog.GetString("Syncronized browsing enabled"));
+		}
+		
+		
 	}
 }
